@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -48,7 +48,7 @@ class YouTubeWebHelper(BaseWebHelper):
             (path, env) = get_youtube_dl()
             # Remove playlist args
             uri = sub("list=.*", "", uri)
-            argv = [path, "-g", "-f", "bestaudio", uri]
+            argv = [path, "--no-cache-dir", "-g", "-f", "bestaudio", uri]
             if proxy is not None:
                 argv += ["--proxy", proxy, None]
             else:
