@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -143,7 +143,7 @@ class Playlists(GObject.GObject):
                         WHERE rowid=?",
                         (name, playlist_id))
         emit_signal(self, "playlists-renamed", playlist_id)
-        App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
+        App().art.remove_from_cache("playlist_" + name, "ROUNDED")
 
     def remove(self, playlist_id):
         """
@@ -159,7 +159,7 @@ class Playlists(GObject.GObject):
                         WHERE playlist_id=?",
                         (playlist_id,))
         emit_signal(self, "playlists-removed", playlist_id)
-        App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
+        App().art.remove_from_cache("playlist_" + name, "ROUNDED")
 
     def clear(self, playlist_id):
         """
@@ -318,6 +318,8 @@ class Playlists(GObject.GObject):
         elif playlist_id == Type.RANDOMS:
             track_ids = App().tracks.get_randoms([], storage_type,
                                                  False, limit)
+        elif playlist_id == Type.SKIPPED:
+            track_ids = App().tracks.get_skipped(storage_type)
         elif playlist_id == Type.ALL:
             track_ids = App().tracks.get_ids(storage_type, False)
         elif playlist_id == Type.LOVED:
@@ -410,6 +412,7 @@ class Playlists(GObject.GObject):
                     "sync-internal-ids").get_string()
             try:
                 data = json.loads(internal_ids)
+                data.keys()
             except:
                 data = {}
             synced_ids = []
@@ -437,6 +440,7 @@ class Playlists(GObject.GObject):
                     "sync-internal-ids").get_string()
             try:
                 data = json.loads(internal_ids)
+                data.keys()
             except:
                 data = {}
             synced_ids = []
@@ -492,6 +496,7 @@ class Playlists(GObject.GObject):
                 "sync-internal-ids").get_string()
             try:
                 data = json.loads(internal_ids)
+                data.keys()
             except:
                 data = {}
             data[str(playlist_id)] = synced
@@ -526,7 +531,7 @@ class Playlists(GObject.GObject):
         """
         name = self.get_name(playlist_id)
         # Clear cache
-        App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
+        App().art.remove_from_cache("playlist_" + name, "ROUNDED")
         with SqlCursor(self, True) as sql:
             sql.execute("UPDATE playlists\
                         SET smart_sql=?\
@@ -600,7 +605,7 @@ class Playlists(GObject.GObject):
         try:
             name = self.get_name(playlist_id)
             # Clear cache
-            App().art.remove_artwork_from_cache("playlist_" + name, "ROUNDED")
+            App().art.remove_from_cache("playlist_" + name, "ROUNDED")
             playlist_uri = self.get_sync_uri(playlist_id)
             if playlist_uri is None:
                 return
@@ -616,7 +621,7 @@ class Playlists(GObject.GObject):
             stream = f.replace(None, False,
                                Gio.FileCreateFlags.REPLACE_DESTINATION, None)
             stream.write("#EXTM3U\n".encode("utf-8"))
-            playlist_dir_uri = playlist_uri.replace(f.get_basename(), "")
+            playlist_dir_uri = "/".join(playlist_uri.split("/")[:-1]) + "/"
             for uri in uris:
                 if uri.startswith("web://"):
                     continue
