@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -27,4 +27,4 @@ class EqualizerView(View):
         View.__init__(self, StorageType.ALL, ViewType.SCROLLED)
         widget = EqualizerWidget()
         widget.show()
-        self.add(widget)
+        self.add_widget(widget)
