@@ -1,4 +1,4 @@
-# Copyright (c) 2014-2020 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
+# Copyright (c) 2014-2021 Cedric Bellegarde <cedric.bellegarde@adishatz.org>
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -31,10 +31,9 @@ class PlaylistRoundedWidget(RoundedAlbumsWidget, SignalsHelper):
             @param view_type as ViewType
             @param font_height as int
         """
-        self.__font_height = font_height
         name = sortname = App().playlists.get_name(playlist_id)
         RoundedAlbumsWidget.__init__(self, playlist_id, name,
-                                     sortname, view_type)
+                                     sortname, view_type, font_height)
         self._track_ids = []
         self._genre = Type.PLAYLISTS
         return [
@@ -50,15 +49,6 @@ class PlaylistRoundedWidget(RoundedAlbumsWidget, SignalsHelper):
         else:
             self.set_artwork()
 
-    def set_view_type(self, view_type):
-        """
-            Update view type
-            @param view_type as ViewType
-        """
-        RoundedAlbumsWidget.set_view_type(self, view_type)
-        self.set_size_request(self._art_size,
-                              self._art_size + self.__font_height)
-
     @property
     def track_ids(self):
         """
